<template>
  <a-card :bordered="false" :class="'cust-erp-sub-tab'">
    <div>
      <a-table
        ref="table"
        bordered
        size="middle"
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        @change="handleTableChange"
        class="j-table-force-nowrap"
        :scroll="{x:true}"
      >
        <!-- :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}" -->

      </a-table>
    </div>
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction, postAction } from '@/api/manage'
import JInput from '@/components/jeecg/JInput'
import Tooltip from 'ant-design-vue/es/tooltip'
import JEllipsis from "@/components/jeecg/JEllipsis";

export default {
  name: "EquipmentPrecisionParametersList",
  mixins: [JeecgListMixin],
  components: {
    JInput,
    Tooltip,
    JEllipsis,
  },
  props:{
    calibrationOrderId:{
        type:String,
        default:'',
        required:false
    }
  },
    watch:{
      calibrationOrderId:{
        immediate: true,
        handler(val) {
          if(!this.calibrationOrderId){
            this.clearList()
          }else{
            this.queryParam['calibrationOrderId'] = val;
            this.queryParam['delFlag'] = 0;
            this.loadData(1);
          }
        }
      }
    },
  data() {
    return {
      description: '精度参数',
      disableMixinCreated:true,
      ipagination:{
          current: 1,
          pageSize: 5,
          pageSizeOptions: ['5', '10', '50'],
          showTotal: (total, range) => {
            return range[0] + "-" + range[1] + " 共" + total + "条"
          },
          showQuickJumper: true,
          showSizeChanger: true,
          total: 0
      },
      // 表头
      columns: [
          {
            title: '#',
            dataIndex:'sort',
            width:100,
            align:"center",
          },
          {
            title:'检验项目名称',
            align:"center",
            dataIndex: 'name',
            width:200
          },
          {
            title:'位置',
            align:"center",
            dataIndex: 'precisionParametersUda1',
            width:200
          },
          {
            title:'允差（mm）',
            align:"center",
            dataIndex: 'tolerance',
            width:200
          },
          {
            title:'实测值',
            align:"center",
            dataIndex: 'actualValue',
            width:200
          },
      ],
      url: {
        list: "/eam/calibrationOrder/listByMainId",
      },
    }
  },
  methods: {
    clearList(){
        this.dataSource=[]
        this.selectedRowKeys=[]
        this.ipagination.current = 1
    },
  },
  computed: {
      importExcelUrl(){
        return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
      }
  },
}
</script>

<style scoped>
@import '~@assets/less/common.less';
 .frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
</style>